import { Metadata, Loader, Http } from '@zeedhi/core';
import { AlertService } from '@zeedhi/common';
import { CrosstabEditable } from '@zeedhi/zd-crosstab-common';
import BudgetParameters from '@/controllers/BudgetParameters';
import { ZdTreeGrid } from '@zeedhi/vuetify';

export class CalculationOperatingBudgetController {
  public editing = false;
  
  public filter;
  
  public titleBudget: string = 'Nenhum filtro aplicado.';
  
  public async mounted() {
    await BudgetParameters.getBudgetParameters();
    const filterOperatingBudgetModal = Loader.getInstance('FilterOperatingBudgetModalController');
    filterOperatingBudgetModal.createfilterOperatingBudgetModal();
  }
  
  public defineTitleBudget() {
    let title = '';
    if (this.filter) {
      const year = this.filter.NRANOORCAGOP;
      const period = !this.filter.NRPERIODOORCA || this.filter.NRPERIODOORCA.IDPERIODOORCA === 'ANUAL'
        ? this.filter.IDPERIODOORCA : this.filter.NRPERIODOORCA.DSPERIODOORCA;
      const manager = BudgetParameters.getParameters.NMOPERADOR;
      title = 'Ano'.concat(': ', year, ' - ', 'Período', ': ', period, ' - ', 'Gerente Operacional', ': ', manager);
      this.titleBudget = title;
    }
    this.initialize();
  }
  
  public tableData(component) {
    // const formatting = new Utilities();
    const routeName = component.name;
    const filtered = BudgetParameters.getParametersHandled;
    // const selectedData = component.datasource.filter.SELECTED;
    const sendObject = {
      filter: [],
    };
    sendObject.filter.push(...filtered);
    let data;
    
    Http.post(`/${routeName}`, sendObject).then((response) => {
      data = response.data.dataset[routeName].map((obj) => {
        Object.keys(obj).forEach((key) => {
          if (typeof obj[key] === 'number') {
            obj[key] = 0;
            // formatting.formatValue('float', obj[key]);
          }
        });
      
        return obj;
      });
      component.datasource.setFilter([]);
      component.datasource.updateData(data);
    });
  }
  
  public initialize() {
    const instance = Metadata.getInstance<ZdTreeGrid>('gridSummary');
    this.tableData(instance);
  }

  get isNotEditing() {
    return !this.editing;
  }
  
  public yearDescription() {
    
  }
  
  public formattedValue() {
    
  }

  public async saveEdit() {
    const instance = Metadata.getInstance<CrosstabEditable>('crosstab-editable-example');
    try {
      await instance.saveEditedRows();
      AlertService.show({ name: 'save', text: 'Salvo com sucesso!', color: 'success' });
    } catch (e) {
      AlertService.show({ name: 'save', text: 'Houve um erro', color: 'error' });
    }
  }

  public cancelEdit() {
    const instance = Metadata.getInstance<CrosstabEditable>('crosstab-editable-example');
    instance.cancelEditedRows();
  }
  
  // public getBudgetParameters() {
  //   const routeName = 'budgetParameters';
  //   const columnName = 'budgetParameters';
  //   const sendObject = {
  //     filter: [],
  //   };
    
  //   Http.post(`/${routeName}`, sendObject).then((response) => {
  //     /* eslint no-console: ["error", { allow: ["warn", "error", "info", "log"] }] */
  //     const data = response.data.dataset[routeName];
  //     const [firstRecord] = Array.isArray(data) ? data : [];
    
  //     this[columnName] = firstRecord.VALUE;
  //   });
  // }
}
